@@ -8,7 +8,6 @@
 #define CURLALTSVC_H1_FIRST 0x074001 /* Added in 7.64.1 */
 #define CURLALTSVC_H2_FIRST 0x074001 /* Added in 7.64.1 */
 #define CURLALTSVC_H3_FIRST 0x074001 /* Added in 7.64.1 */
-#define CURLALTSVC_IMMEDIATELY_FIRST 0x074001 /* Added in 7.64.1 */
 #define CURLALTSVC_READONLYFILE_FIRST 0x074001 /* Added in 7.64.1 */
 #define CURLAUTH_ANY_FIRST 0x070a06 /* Added in 7.10.6 */
 #define CURLAUTH_ANYSAFE_FIRST 0x070a06 /* Added in 7.10.6 */
@@ -209,6 +208,8 @@
 #define CURLGSSAPI_DELEGATION_POLICY_FLAG_FIRST 0x071600 /* Added in 7.22.0 */
 #define CURLHEADER_SEPARATE_FIRST 0x072500 /* Added in 7.37.0 */
 #define CURLHEADER_UNIFIED_FIRST 0x072500 /* Added in 7.37.0 */
+#define CURLHSTS_ENABLE_FIRST 0x074a00 /* Added in 7.74.0 */
+#define CURLHSTS_READONLYFILE_FIRST 0x074a00 /* Added in 7.74.0 */
 #define CURLINFO_ACTIVESOCKET_FIRST 0x072d00 /* Added in 7.45.0 */
 #define CURLINFO_APPCONNECT_TIME_FIRST 0x071300 /* Added in 7.19.0 */
 #define CURLINFO_APPCONNECT_TIME_T_FIRST 0x073d00 /* Added in 7.61.0 */
@@ -441,6 +442,12 @@
 #define CURLOPT_HEADERDATA_FIRST 0x070a00 /* Added in 7.10 */
 #define CURLOPT_HEADERFUNCTION_FIRST 0x070702 /* Added in 7.7.2 */
 #define CURLOPT_HEADEROPT_FIRST 0x072500 /* Added in 7.37.0 */
+#define CURLOPT_HSTS_FIRST 0x074a00 /* Added in 7.74.0 */
+#define CURLOPT_HSTS_CTRL_FIRST 0x074a00 /* Added in 7.74.0 */
+#define CURLOPT_HSTSREADDATA_FIRST 0x074a00 /* Added in 7.74.0 */
+#define CURLOPT_HSTSREADFUNCTION_FIRST 0x074a00 /* Added in 7.74.0 */
+#define CURLOPT_HSTSWRITEDATA_FIRST 0x074a00 /* Added in 7.74.0 */
+#define CURLOPT_HSTSWRITEFUNCTION_FIRST 0x074a00 /* Added in 7.74.0 */
 #define CURLOPT_HTTP09_ALLOWED_FIRST 0x074000 /* Added in 7.64.0 */
 #define CURLOPT_HTTP200ALIASES_FIRST 0x070a03 /* Added in 7.10.3 */
 #define CURLOPT_HTTPAUTH_FIRST 0x070a06 /* Added in 7.10.6 */
@@ -821,6 +828,9 @@
 #define CURLSSLSET_OK_FIRST 0x073800 /* Added in 7.56.0 */
 #define CURLSSLSET_TOO_LATE_FIRST 0x073800 /* Added in 7.56.0 */
 #define CURLSSLSET_UNKNOWN_BACKEND_FIRST 0x073800 /* Added in 7.56.0 */
+#define CURLSTS_DONE_FIRST 0x074a00 /* Added in 7.74.0 */
+#define CURLSTS_FAIL_FIRST 0x074a00 /* Added in 7.74.0 */
+#define CURLSTS_OK_FIRST 0x074a00 /* Added in 7.74.0 */
 #define CURLUE_BAD_HANDLE_FIRST 0x073e00 /* Added in 7.62.0 */
 #define CURLUE_BAD_PARTPOINTER_FIRST 0x073e00 /* Added in 7.62.0 */
 #define CURLUE_BAD_PORT_NUMBER_FIRST 0x073e00 /* Added in 7.62.0 */
@@ -1023,6 +1033,7 @@
 #define CURL_VERSION_DEBUG_FIRST 0x070a06 /* Added in 7.10.6 */
 #define CURL_VERSION_GSSAPI_FIRST 0x072600 /* Added in 7.38.0 */
 #define CURL_VERSION_GSSNEGOTIATE_FIRST 0x070a06 /* Added in 7.10.6 */
+#define CURL_VERSION_HSTS_FIRST 0x074a00 /* Added in 7.74.0 */
 #define CURL_VERSION_HTTP2_FIRST 0x072100 /* Added in 7.33.0 */
 #define CURL_VERSION_HTTP3_FIRST 0x074200 /* Added in 7.66.0 */
 #define CURL_VERSION_HTTPS_PROXY_FIRST 0x073400 /* Added in 7.52.0 */
